@@ -83,11 +83,7 @@ impl<'a> LogcatWriter<'a> {
 }
 impl<'a> io::Write for LogcatWriter<'a> {
     fn write(&mut self, buf: &[u8]) -> io::Result<usize> {
-        let written = if buf.len() > LOGGING_MSG_MAX_LEN {
-            LOGGING_MSG_MAX_LEN - buf.len()
-        } else {
-            buf.len()
-        };
+        let written = buf.len().min(LOGGING_MSG_MAX_LEN);
         self.log(&buf[..written])?;
         Ok(written)
     }
